@@ -9,8 +9,9 @@ from commodity.str_ import Printable
 from commodity.log import UniqueFilter
 from commodity.pattern import memoizedproperty
 from commodity.log import CallerData
+from commodity.path import child_relpath
 
-from .const import Status, INDENTST, term, IDENTIFIERS
+from .const import Status, INDENTST, term, IDENTIFIERS, PREGO_TMP
 from .exc import (PregoAssertionException, log_traceback)
 from .tools import Interpolator
 from .item import File
@@ -212,15 +213,19 @@ class Task(Printable):
         self.gen.extend([File(x) for x in fnames])
 
     def remove_gen(self):
+        def get_relpaths(files):
+            return [child_relpath(f.path, start=PREGO_TMP) for f in files]
+
         if not self.gen:
             return
 
         if config.dirty:
-            self.log.info('%s  $name dirty mode: generated files not removed',
-                          Status.indent())
+            self.log.info('%s  $name dirty mode: generated files not removed: %s ',
+                          Status.indent(), get_relpaths(self.gen))
             return
 
-        self.log.debug("%s$name   removing %s", INDENTST, self.gen)
+        self.log.debug("%s$name   removing %s", INDENTST, get_relpaths(self.gen))
+
         for f in self.gen:
             f.remove()
 
@@ -235,7 +240,7 @@ class Running(Matcher):
         return cmd.is_running()
 
     def describe_to(self, description):
-        description.append_text('is running ')
+        description.append_text('running ')
 
 
 def running():
